==> gcstar_0.5.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/DE/GCModels/GCgames.pm <==
{
    package GCLang::DE::GCModels::GCgames;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Computerspiele Sammlung',
        Items => 'Spiele',
        NewItem => 'Neues Spiel',
    
        Id => 'Id',
        Name => 'Name',
        Platform => 'Plattform',
        Players => 'Anzahl der Spieler',
        Released => 'Erscheinungsdatum',
        Editor => 'Editor',
        Genre => 'Genre',
        Box => 'Bild der Schachtel',
        Rating => 'Bewertung',
        Completion => 'Durchgespielt (%)',
        Description => 'Beschreibung',
        Codes => 'Codes',
        Code => 'Code',
        Effect => 'Effekte',
        Secrets => 'Geheimnisse',
        Location => 'Ort',
        Screenshots => 'Bildschirm Foto',
        Screenshot1 => 'Erstes Bildschirm Foto',
        Screenshot2 => 'Zweites Bildschirm Foto',
        Url => 'Internetseite',
        Unlockables => 'Unlockables',
        Unlockable => 'Unlockable',
        Howto => 'How to unlock',

        General => 'Allgemein',
        Details => 'Details',
        Tips => 'Tips',
        Information => 'Information',

        FilterRatingSelect => 'Rating At _Least...',
     );
}

1;

==> gcstar_1.0.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/DE/GCModels/GCgames.pm <==
{
    package GCLang::DE::GCModels::GCgames;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Computerspiele Sammlung',
        Items => 'Spiele',
        NewItem => 'Neues Spiel',
    
        Id => 'Id',
        Name => 'Name',
        Platform => 'Plattform',
        Players => 'Anzahl der Spieler',
        Released => 'Erscheinungsdatum',
        Editor => 'Editor',
        Genre => 'Genre',
        Box => 'Bild der Schachtel',
        Rating => 'Bewertung',
        Completion => 'Durchgespielt (%)',
        Description => 'Beschreibung',
        Codes => 'Cheats',
        Code => 'Cheatcode',
        Effect => 'Effekt',
        Secrets => 'Geheimnisse',
        Location => 'Ort',
        Screenshots => 'Bildschirm Foto',
        Screenshot1 => 'Erstes Bildschirm Foto',
        Screenshot2 => 'Zweites Bildschirm Foto',
        Comments => 'Kommentar',
        Url => 'Internetseite',
        Unlockables => 'Lösungen',
        Unlockable => 'Ziel',
        Howto => 'Lösungsweg',

        General => 'Allgemein',
        Details => 'Details',
        Tips => 'Tipps',
        Information => 'Information',

        FilterRatingSelect => 'Bewertung _mindestens ...',
     );
}

1;
